@@ -263,7 +263,7 @@ void command_property(gpointer callback_data,guint callback_action,
 	ft.ft_id=ptw->ft_id;
 	ft.margin=ptw->margin;
 	ft.tab=ptw->tab;
-	ft.code=ptw->code;
+	ft.autoindent=ptw->autoindent;
 	ft.crlf=ptw->crlf;
 	ft.eof=ptw->eof;
 	ft.limit=ptw->limit;
@@ -288,6 +288,7 @@ void command_property(gpointer callback_data,guint callback_action,
 				if (ftype[i].ft_id==ft.ft_id) {
 					ftype[i].margin=ft.margin;
 					ftype[i].tab=ft.tab;
+					ftype[i].autoindent=ft.autoindent;
 					ftype[i].code=ft.code;
 					ftype[i].crlf=ft.crlf;
 					ftype[i].eof=ft.eof;
