@@ -235,15 +235,7 @@ gint get_screen_pos(TEXTWND *ptw,gint x,gint y)
 	   RET,ʬ																*/
 guint get_char_type(gchar *text,gint length)
 {
-	if (length>1)
-		return 8;
-	if ((*text&0x80)!=0)
-		return 4;
-	if (('A'<=*text && *text<='Z') || ('a'<=*text && *text<='z'))
-		return 2;
-	if ('0'<=*text && *text<='9')
-		return 1;
-	return 0;
+	return charset_type(text,length)&~(CS_CONTROL|CS_SPACE|CS_PUNCT|CS_SYMBOL);
 }
 
 
