@@ -270,9 +270,11 @@ TEXTWND *open_edit_file(gchar *file)
 		/*  */
 		ptw->file=g_strdup_printf("new%04d",fcount++%1000);
 		ptw->create=TRUE;
+		i=0;
 		ptw->ft_id=ftype[0].associate?ftype[0].ft_id:-1;
 		ptw->margin=ftype[0].margin;
 		ptw->tab=ftype[0].tab;
+		ptw->autoindent=ftype[0].autoindent;
 		ptw->code=ftype[0].code;
 		ptw->crlf=ftype[0].crlf;
 		ptw->eof=ftype[0].eof;
@@ -307,6 +309,7 @@ TEXTWND *open_edit_file(gchar *file)
 		ptw->ft_id=ftype[i].associate?ftype[i].ft_id:-1;
 		ptw->margin=ftype[i].margin;
 		ptw->tab=ftype[i].tab;
+		ptw->autoindent=ftype[i].autoindent;
 		ptw->code=ftype[i].code;
 		ptw->crlf=ftype[i].crlf;
 		ptw->eof=ftype[i].eof;
