@@ -187,29 +187,19 @@ void format_dialog(void)
 	button5=gtk_button_new_with_label(_("Ĥ"));
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
 																_("(_N)"));
-	gtk_widget_add_accelerator(button0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
 																_("(_R)"));
-	gtk_widget_add_accelerator(button1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),
 																_("(_U)"));
-	gtk_widget_add_accelerator(button2,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button2,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button3)->child),
 																_("(_D)"));
-	gtk_widget_add_accelerator(button3,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button3,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button4)->child),
 																_("Խ(_E)"));
-	gtk_widget_add_accelerator(button4,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button4,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 										format_dialog_clicked_new,clist);
 	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
