@@ -110,14 +110,13 @@ gboolean ftype_dialog(gint *pos)
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
 										GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
 	/* ܥå */
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),scroll,TRUE,TRUE,8);
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),scroll,TRUE,TRUE,8);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
 	/* ɽ */
