@@ -32,8 +32,8 @@ static gint ft_id;
 static GdkColor gdk_color[12];
 static GtkWidget *dialog;
 static GtkWidget *button0,*button3;
-static GtkWidget *check0,*check1,*check2,*check3,*check4,*check5;
-static GtkWidget *check6,*check7,*check8,*check9,*check10,*check11;
+static GtkWidget *check0,*check1,*check2,*check3,*check4,*check5,*check6;
+static GtkWidget *check7,*check8,*check9,*check10,*check11,*check12;
 static GtkWidget *clist,*entry0,*entry1,*label,*spin0,*spin1;
 static gchar *color_name[12]={N_("ʸ"),N_("ط"),N_("ȥ륳"),
 					N_("ѥڡ"),N_("ԥ"),N_("ֲ"),
@@ -55,7 +55,7 @@ static void property_dialog_toggled(GtkWidget *widget,gpointer user_data)
 {
 	gtk_clist_unselect_all(GTK_CLIST(clist));
 	gtk_widget_set_sensitive(clist,
-					!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check10)));
+					!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check11)));
 	gtk_widget_set_sensitive(button0,FALSE);
 	property_dialog_ok_sensitive(widget,user_data);
 }
@@ -214,10 +214,12 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check7),
 														ftype[pos].vline);
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check8),
-														ftype[pos].eof);
+														ftype[pos].autoindent);
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check9),
-														ftype[pos].overwrite);
+														ftype[pos].eof);
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check10),
+														ftype[pos].overwrite);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check11),
 														ftype[pos].syscol);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),
 														ftype[pos].margin);
@@ -257,11 +259,12 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FTYPE *ft)
 	ft->code=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check5));
 	ft->uline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check6));
 	ft->vline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check7));
-	ft->eof=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check8));
-	ft->overwrite=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check9));
-	ft->syscol=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check10));
-	if (check11!=NULL)
-		ft->associate=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check11));
+	ft->autoindent=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check8));
+	ft->eof=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check9));
+	ft->overwrite=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check10));
+	ft->syscol=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check11));
+	if (check12!=NULL)
+		ft->associate=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check12));
 	memcpy(ft->color,gdk_color,sizeof(GdkColor)*12);
 	g_free(ft->fontname);
 	ft->fontname=fontname;
@@ -360,6 +363,7 @@ gboolean property_dialog(FTYPE *ft)
 	check8=gtk_check_button_new_with_label(NULL);
 	check9=gtk_check_button_new_with_label(NULL);
 	check10=gtk_check_button_new_with_label(NULL);
+	check11=gtk_check_button_new_with_label(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
 															_("å(_G)"));
 	gtk_widget_add_accelerator(check0,"clicked",accel,key,GDK_MOD1_MASK,0);
@@ -383,14 +387,17 @@ gboolean property_dialog(FTYPE *ft)
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check7)->child),_("(_V)"));
 	gtk_widget_add_accelerator(check7,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check8)->child),
-									_("եκǸ^Z(1A)դ(_Z)"));
+														_("ư(_N)"));
 	gtk_widget_add_accelerator(check8,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check9)->child),
-												_("¸ǧ(_O)"));
+									_("եκǸ^Z(1A)դ(_Z)"));
 	gtk_widget_add_accelerator(check9,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check10)->child),
-													_("ƥ࿧Ȥ(_Y)"));
+												_("¸ǧ(_O)"));
 	gtk_widget_add_accelerator(check10,"clicked",accel,key,GDK_MOD1_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check11)->child),
+													_("ƥ࿧Ȥ(_Y)"));
+	gtk_widget_add_accelerator(check11,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),ft->gline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),ft->space);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),ft->crlf);
@@ -399,9 +406,10 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check5),ft->code);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check6),ft->uline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check7),ft->vline);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check8),ft->eof);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check9),ft->overwrite);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check10),ft->syscol);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check8),ft->autoindent);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check9),ft->eof);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check10),ft->overwrite);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check11),ft->syscol);
 	gtk_signal_connect(GTK_OBJECT(check0),"toggled",
 											property_dialog_ok_sensitive,NULL);
 	gtk_signal_connect(GTK_OBJECT(check1),"toggled",
@@ -423,17 +431,20 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_signal_connect(GTK_OBJECT(check9),"toggled",
 											property_dialog_ok_sensitive,NULL);
 	gtk_signal_connect(GTK_OBJECT(check10),"toggled",
+											property_dialog_ok_sensitive,NULL);
+	gtk_signal_connect(GTK_OBJECT(check11),"toggled",
 											property_dialog_toggled,NULL);
 	if (ft->text!=NULL && ft->ext!=NULL) {
-		check11=gtk_check_button_new_with_label(NULL);
-		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check11)->child),
+		check12=gtk_check_button_new_with_label(NULL);
+		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check12)->child),
 										_("ե륿פϢŤ(_A)"));
-		gtk_widget_add_accelerator(check11,"clicked",accel,key,GDK_MOD1_MASK,0);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check11),ft->associate);
-		gtk_signal_connect(GTK_OBJECT(check11),"toggled",
+		gtk_widget_add_accelerator(check12,"clicked",accel,
+														key,GDK_MOD1_MASK,0);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check12),ft->associate);
+		gtk_signal_connect(GTK_OBJECT(check12),"toggled",
 											property_dialog_ok_sensitive,NULL);
 	} else {
-		check11=NULL;
+		check12=NULL;
 	}
 	/* ȥ꡼/٥ */
 	label=NULL;
@@ -554,18 +565,19 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(hbox),check7,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame2),hbox);
 
-	frame3=gtk_frame_new(_("¸"));
+	frame3=gtk_frame_new(_("Խ"));
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),check8,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),check9,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),check10,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame3),vbox);
 
 	frame4=gtk_frame_new(_(""));
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),scroll,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),check10,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),check11,FALSE,FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
@@ -589,8 +601,8 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(hbox),button1,FALSE,FALSE,0);
 	if (button2!=NULL)
 		gtk_box_pack_start(GTK_BOX(hbox),button2,FALSE,FALSE,0);
-	if (check11!=NULL)
-		gtk_box_pack_start(GTK_BOX(hbox),check11,FALSE,FALSE,0);
+	if (check12!=NULL)
+		gtk_box_pack_start(GTK_BOX(hbox),check12,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button4,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button3,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
