@@ -823,25 +823,33 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 
 	switch (event->keyval) {
 	case GDK_Home:
-	case GDK_Left:
-	case GDK_Up:
-	case GDK_Right:
-	case GDK_Down:
-	case GDK_Page_Up:
-	case GDK_Page_Down:
+	case GDK_KP_Home:
 	case GDK_End:
-	case GDK_comma:
-	case GDK_period:
-	case GDK_less:
-	case GDK_greater:
+	case GDK_KP_End:
 	case GDK_H:
-	case GDK_J:
-	case GDK_K:
-	case GDK_L:
 	case GDK_h:
-	case GDK_j:
-	case GDK_k:
+	case GDK_Left:
+	case GDK_KP_Left:
+	case GDK_L:
 	case GDK_l:
+	case GDK_Right:
+	case GDK_KP_Right:
+	case GDK_comma:
+	case GDK_less:
+	case GDK_period:
+	case GDK_greater:
+	case GDK_K:
+	case GDK_k:
+	case GDK_Up:
+	case GDK_KP_Up:
+	case GDK_J:
+	case GDK_j:
+	case GDK_Down:
+	case GDK_KP_Down:
+	case GDK_Page_Up:
+	case GDK_KP_Page_Up:
+	case GDK_Page_Down:
+	case GDK_KP_Page_Down:
 		{
 			gint sx,sy,width;
 			gboolean alt,ctrl;
@@ -855,11 +863,13 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 			ctrl=(event->state&GDK_CONTROL_MASK)!=0;
 			switch (event->keyval) {
 			case GDK_Home:
+			case GDK_KP_Home:
 				ptw->cursor.x=0;
 				if (ctrl)
 					ptw->cursor.y=0;
 				break;
 			case GDK_End:
+			case GDK_KP_End:
 				ptw->cursor.x=get_width(ptw,
 								ctrl?ptw->cursor.y=ptw->max-1:ptw->cursor.y);
 				break;
@@ -868,6 +878,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				if (!alt)
 					goto loop;
 			case GDK_Left:
+			case GDK_KP_Left:
 				ptw->cursor.x=get_align_pos(ptw,
 											ptw->cursor.x,ptw->cursor.y,FALSE);
 				if (ptw->cursor.x>0) {
@@ -886,6 +897,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				if (!alt)
 					goto loop;
 			case GDK_Right:
+			case GDK_KP_Right:
 				width=get_width(ptw,ptw->cursor.y);
 				if (ptw->cursor.x<width) {
 					ptw->cursor.x=ctrl?get_move_pos(ptw,
@@ -932,6 +944,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				if (!alt)
 					goto loop;
 			case GDK_Up:
+			case GDK_KP_Up:
 				if (!ctrl) {
 					ptw->cursor.y--;
 				} else if (ptw->top.y>0) {
@@ -945,6 +958,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				if (!alt)
 					goto loop;
 			case GDK_Down:
+			case GDK_KP_Down:
 				if (!ctrl) {
 					ptw->cursor.y++;
 				} else if (ptw->top.y<ptw->max-sy) {
@@ -954,6 +968,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				}
 				break;
 			case GDK_Page_Up:
+			case GDK_KP_Page_Up:
 				if (ctrl) {
 					ptw->cursor.y=ptw->top.y;
 				} else {
@@ -962,6 +977,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				}
 				break;
 			case GDK_Page_Down:
+			case GDK_KP_Page_Down:
 				if (ctrl) {
 					ptw->cursor.y=ptw->top.y+sy-1;
 				} else {
@@ -1061,13 +1077,27 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 	case GDK_ISO_Enter:
 	case GDK_3270_Enter:
 		{
+			gchar *text;
+			gint i,datapos;
 			DOING *d;
+			LINEBUF *p;
 			GdkPoint select;
 
-			if ((event->state&GDK_MODIFIER_MASK)!=0)
-				break;
 			select=ptw->select;
-			d=edit_operation(ptw,"\n",1,TRUE,FALSE);
+			if (ptw->autoindent) {
+				datapos=get_data_pos(ptw,ptw->cursor.x,ptw->cursor.y,FALSE);
+				p=get_line_buf(&ptw->start,&ptw->off,ptw->cursor.y);
+				for (i=0;i<datapos;i++)
+					if (p->text[i]!='\t' && p->text[i]!=' ')
+						break;
+				text=g_malloc((i+1)*sizeof(gchar));
+				text[0]='\n';
+				memcpy(text+1,p->text,i*sizeof(gchar));
+				d=edit_operation(ptw,text,i+1,TRUE,FALSE);
+				g_free(text);
+			} else {
+				d=edit_operation(ptw,"\n",1,TRUE,FALSE);
+			}
 			d->next=ptw->undo;
 			ptw->undo=d;
 			if (delete_list(&ptw->redo)>0 || d->next==NULL || select.x>=0)
@@ -1076,7 +1106,47 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 		}
 		result=TRUE;
 		break;
+	case GDK_Tab:
+	case GDK_KP_Tab:
+		{
+			DOING *d;
+			GdkPoint select;
+
+			if ((event->state&(GDK_CONTROL_MASK|GDK_MOD1_MASK))==0) {
+				select=ptw->select;
+				d=edit_operation(ptw,"\t",1,TRUE,FALSE);
+				d->next=ptw->undo;
+				ptw->undo=d;
+				if (delete_list(&ptw->redo)>0 || d->next==NULL || select.x>=0)
+					set_menu_bar(ptw);
+				ptw->edit=TRUE;
+			} else {
+				gint page;
+				guint length;
+				GList *glist;
+
+				glist=gtk_container_children(GTK_CONTAINER(notebook));
+				length=g_list_length(glist);
+				g_list_free(glist);
+				page=gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
+				if ((event->state&GDK_SHIFT_MASK)==0) {
+					if (++page>=length)
+						page=0;
+				} else {
+					if (--page<0)
+						page=length-1;
+				}
+				gtk_notebook_set_page(GTK_NOTEBOOK(notebook),page);
+				gtk_widget_grab_focus(((TEXTWND *)
+					gtk_object_get_user_data(GTK_OBJECT(
+					gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),page))))->
+																	drawing);
+			}
+		}
+		result=TRUE;
+		break;
 	case GDK_Escape:
+	case GDK_Cancel:
 		{
 			gint sx,sy;
 			GdkPoint select,top;
@@ -1110,6 +1180,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 		result=TRUE;
 		break;
 	case GDK_Delete:
+	case GDK_KP_Delete:
+	case GDK_3270_DeleteWord:
 		{
 			gint width;
 			DOING *d;
@@ -1143,6 +1215,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 		result=TRUE;
 		break;
 	case GDK_Insert:
+	case GDK_KP_Insert:
 		ins=!ins;
 		draw_caret(ptw,NULL);
 		result=TRUE;
@@ -1188,6 +1261,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 			gint sx,sy;
 			GdkPoint top;
 
+			if ((event->state&GDK_SHIFT_MASK)==0)
+				break;
 			top=ptw->top;
 			sx=MAX(ptw->drawing->allocation.width/ptw->fontwidth,1);
 			sy=MAX(ptw->drawing->allocation.height/ptw->fontheight,1);
@@ -1206,44 +1281,53 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 			if (ptw->top.y!=top.y)
 				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
 										0,ptw->max-1,sy,ptw->top.y);
-		}
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(
+			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
 				item_factory_popup,_("<main>/᤹(U)")),ptw->undo!=NULL);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(
+			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
 				item_factory_popup,_("<main>/ڤ(T)")),ptw->select.x>=0);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(
+			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
 				item_factory_popup,_("<main>/ԡ(C)")),ptw->select.x>=0);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(
+			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
 				item_factory_popup,_("<main>/(L)")),ptw->select.x>=0);
-		gtk_menu_popup(GTK_MENU(
+			gtk_menu_popup(GTK_MENU(
 					gtk_item_factory_get_widget(item_factory_popup,"<main>")),
 											NULL,NULL,NULL,NULL,3,event->time);
+		}
 		result=TRUE;
 		break;
 	default:
 		loop:
-		if (event->string!=NULL
-				&& ((guchar)event->string[0]>=' ' || event->string[0]=='\t')
-										&& (event->state&GDK_MOD1_MASK)==0) {
+		if (event->length>0 && (event->state&GDK_MOD1_MASK)==0) {
+			gint i,length;
 			DOING *d;
 			GdkPoint select;
 
-			select=ptw->select;
-			ptw->cursor.x=get_align_pos(ptw,ptw->cursor.x,ptw->cursor.y,FALSE);
-			if (ptw->select.x<0 && !ins) {
-				ptw->select.x=get_align_pos(ptw,
+			for (i=0;i<event->length;i+=length) {
+				length=charset_length(event->string[i]);
+				if (i+length>event->length)
+					length=1;
+				if ((charset_type(event->string+i,length)&CS_CONTROL)!=0)
+					break;
+			}
+			if (i>=event->length) {
+				select=ptw->select;
+				ptw->cursor.x=get_align_pos(ptw,
+											ptw->cursor.x,ptw->cursor.y,FALSE);
+				if (ptw->select.x<0 && !ins) {
+					ptw->select.x=get_align_pos(ptw,
 										ptw->cursor.x+1,ptw->cursor.y,TRUE);
-				if (ptw->select.x<=ptw->cursor.x)
-					ptw->select.x=-1;
-				ptw->select.y=ptw->cursor.y;
+					if (ptw->select.x<=ptw->cursor.x)
+						ptw->select.x=-1;
+					ptw->select.y=ptw->cursor.y;
+				}
+				d=edit_operation(ptw,event->string,event->length,TRUE,FALSE);
+				d->next=ptw->undo;
+				ptw->undo=d;
+				if (delete_list(&ptw->redo)>0 || d->next==NULL || select.x>=0)
+					set_menu_bar(ptw);
+				ptw->edit=TRUE;
+				result=TRUE;
 			}
-			d=edit_operation(ptw,event->string,event->length,TRUE,FALSE);
-			d->next=ptw->undo;
-			ptw->undo=d;
-			if (delete_list(&ptw->redo)>0 || d->next==NULL || select.x>=0)
-				set_menu_bar(ptw);
-			ptw->edit=TRUE;
-			result=TRUE;
 		}
 	}
 	return result;
@@ -1376,6 +1460,8 @@ void signal_activate_menu_window(GtkWidget *widget,GtkWidget *child)
 {
 	gtk_notebook_set_page(GTK_NOTEBOOK(notebook),
 						gtk_notebook_page_num(GTK_NOTEBOOK(notebook),child));
+	gtk_widget_grab_focus(
+			((TEXTWND *)gtk_object_get_user_data(GTK_OBJECT(child)))->drawing);
 }
 
 
@@ -1452,18 +1538,16 @@ gboolean signal_selection_clear(GtkWidget *widget,GdkEventSelection *event,
 
 
 void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
-									guint info,guint time,gpointer user_data)
+											guint info,guint time,TEXTWND *ptw)
 {
 	gchar *text=NULL;
 	guchar *compound_text;
 	gint length=0,compound_length,format;
-	TEXTWND *ptw;
 	GdkAtom encoding;
 
 	if (data->selection==GDK_SELECTION_PRIMARY) {
 		/* ץ饤ޥꥻ쥯 */
-		ptw=user_data;
-		if (ptw->select.x>=0) {
+		if (ptw!=NULL && ptw->select.x>=0) {
 			length=get_sel_bytes(ptw,&ptw->select,&ptw->cursor);
 			text=g_malloc((length+1)*sizeof(gchar));
 			cpy_sel_mem(ptw,&ptw->select,&ptw->cursor,text);
