@@ -306,35 +306,38 @@ int main(int argc,char *argv[])
 			if ((ftype[i].text
 							=profile_get_string(profile,section,"text"))==NULL)
 				ftype[i].text=g_strdup("UNKNOW");
-			if ((ftype[i].ext
-							=profile_get_string(profile,section,"ext"))==NULL)
+			if ((ftype[i].ext=profile_get_string(profile,section,"ext"))==NULL)
 				ftype[i].ext=g_strdup("*");
 			if (!profile_get_value(profile,section,"margin",
-								(gpointer)&ftype[i].margin,sizeof(gint),
+									(gpointer)&ftype[i].margin,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 				ftype[i].margin=80;
 			if (!profile_get_value(profile,section,"tab",
-								(gpointer)&ftype[i].tab,sizeof(gint),
+										(gpointer)&ftype[i].tab,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 				ftype[i].tab=8;
 			if (!profile_get_value(profile,section,"associate",
 								(gpointer)&ftype[i].associate,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].associate=TRUE;
+			if (!profile_get_value(profile,section,"autoindent",
+							(gpointer)&ftype[i].autoindent,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+				ftype[i].autoindent=FALSE;
 			if (!profile_get_value(profile,section,"code",
-								(gpointer)&ftype[i].code,sizeof(gboolean),
+									(gpointer)&ftype[i].code,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].code=FALSE;
 			if (!profile_get_value(profile,section,"crlf",
-								(gpointer)&ftype[i].crlf,sizeof(gboolean),
+									(gpointer)&ftype[i].crlf,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].crlf=FALSE;
 			if (!profile_get_value(profile,section,"eof",
-								(gpointer)&ftype[i].eof,sizeof(gboolean),
+									(gpointer)&ftype[i].eof,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].eof=FALSE;
 			if (!profile_get_value(profile,section,"limit",
-								(gpointer)&ftype[i].limit,sizeof(gboolean),
+									(gpointer)&ftype[i].limit,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].limit=FALSE;
 			if (!profile_get_value(profile,section,"overwrite",
@@ -342,7 +345,7 @@ int main(int argc,char *argv[])
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].overwrite=FALSE;
 			if (!profile_get_value(profile,section,"space",
-								(gpointer)&ftype[i].space,sizeof(gboolean),
+									(gpointer)&ftype[i].space,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].space=FALSE;
 			if (!profile_get_value(profile,section,"syscol",
@@ -350,19 +353,19 @@ int main(int argc,char *argv[])
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].syscol=TRUE;
 			if (!profile_get_value(profile,section,"gline",
-								(gpointer)&ftype[i].gline,sizeof(gboolean),
+									(gpointer)&ftype[i].gline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].gline=FALSE;
 			if (!profile_get_value(profile,section,"mline",
-								(gpointer)&ftype[i].mline,sizeof(gboolean),
+									(gpointer)&ftype[i].mline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].mline=FALSE;
 			if (!profile_get_value(profile,section,"uline",
-								(gpointer)&ftype[i].uline,sizeof(gboolean),
+									(gpointer)&ftype[i].uline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].uline=FALSE;
 			if (!profile_get_value(profile,section,"vline",
-								(gpointer)&ftype[i].vline,sizeof(gboolean),
+									(gpointer)&ftype[i].vline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].vline=FALSE;
 			/* ե */
@@ -501,6 +504,7 @@ int main(int argc,char *argv[])
 		ftype[0].margin=80;
 		ftype[0].tab=8;
 		ftype[0].associate=TRUE;
+		ftype[0].autoindent=FALSE;
 		ftype[0].code=FALSE;
 		ftype[0].crlf=FALSE;
 		ftype[0].eof=FALSE;
@@ -540,8 +544,6 @@ int main(int argc,char *argv[])
 	atom_text=gdk_atom_intern("TEXT",FALSE);
 	atom_textmaid=gdk_atom_intern("Text maid InterProcess communication",
 																		FALSE);
-	gtk_selection_add_targets(window,GDK_SELECTION_PRIMARY,
-							targets,sizeof(targets)/sizeof(GtkTargetEntry));
 	gtk_selection_add_targets(window,atom_clipboard,
 							targets,sizeof(targets)/sizeof(GtkTargetEntry));
 	if (!second)
@@ -818,49 +820,52 @@ int main(int argc,char *argv[])
 									(strlen(ftype[i].text)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			profile_set_value(profile,section,"ext",(gpointer)ftype[i].ext,
-									(strlen(ftype[i].ext)+1)*sizeof(gchar),
+										(strlen(ftype[i].ext)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			profile_set_value(profile,section,"margin",
-								(gpointer)&ftype[i].margin,sizeof(gint),
+									(gpointer)&ftype[i].margin,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 			profile_set_value(profile,section,"tab",
-								(gpointer)&ftype[i].tab,sizeof(gint),
+										(gpointer)&ftype[i].tab,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 			profile_set_value(profile,section,"associate",
 								(gpointer)&ftype[i].associate,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
+			profile_set_value(profile,section,"autoindent",
+							(gpointer)&ftype[i].autoindent,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"code",
-								(gpointer)&ftype[i].code,sizeof(gboolean),
+									(gpointer)&ftype[i].code,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"crlf",
 								(gpointer)&ftype[i].crlf,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"eof",
-								(gpointer)&ftype[i].eof,sizeof(gboolean),
+									(gpointer)&ftype[i].eof,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"limit",
-								(gpointer)&ftype[i].limit,sizeof(gboolean),
+									(gpointer)&ftype[i].limit,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"overwrite",
 								(gpointer)&ftype[i].overwrite,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"space",
-								(gpointer)&ftype[i].space,sizeof(gboolean),
+									(gpointer)&ftype[i].space,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"syscol",
 								(gpointer)&ftype[i].syscol,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"gline",
-								(gpointer)&ftype[i].gline,sizeof(gboolean),
+									(gpointer)&ftype[i].gline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"mline",
-								(gpointer)&ftype[i].mline,sizeof(gboolean),
+									(gpointer)&ftype[i].mline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"uline",
-								(gpointer)&ftype[i].uline,sizeof(gboolean),
+									(gpointer)&ftype[i].uline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"vline",
-								(gpointer)&ftype[i].vline,sizeof(gboolean),
+									(gpointer)&ftype[i].vline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			/* ե */
 			if (ftype[i].fontname!=NULL)
