@@ -103,16 +103,17 @@ void version_dialog(void)
 	pixmap=gdk_pixmap_create_from_xpm_d(window->window,&mask,NULL,tmaid_xpm);
 
 	/* ե졼ȥܥå */
-	vbox=gtk_vbox_new(FALSE,0);
-	hbox=gtk_hbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	hbox=gtk_hbox_new(FALSE,8);
 	gtk_box_pack_start(GTK_BOX(hbox),
-									gtk_pixmap_new(pixmap,mask),FALSE,FALSE,8);
+									gtk_pixmap_new(pixmap,mask),FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new("Text maid version "VERSION
-				"\ncopyright (c) 1998-2002 by Iwamoto,Kazuki"),FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+				"\ncopyright (c) 1998-2002 by Iwamoto,Kazuki"),FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
 	/* ɽ */
